.. include:: /_includes/wip_prolog.rst

:mod:`stix.ttp.exploit_targets` Module
======================================

.. module:: stix.ttp.exploit_targets

Classes
-------

.. autoclass:: ExploitTargets
	:show-inheritance:
	:members:
